@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 __author__ = "Paul Schifferer <dm@sweetrpg.com>"
-"""constants.py
+"""Constants.
 """
 
 SYSTEM_USER_ID = "_system"
